--------------------------------------------------------------------------------------------------------------------------------------------
-- Engineer			: 		Dennis van Elteren
-- 
-- Create Date		:    	August 8th 2015
-- Design Name		: 		My vision system
-- Module Name		:    	POWER ON RESET 
-- Target Devices	: 		xc3s200,xc6slx9
-- Tool versions	: 		ISE14.7
-- Description		: 		This vhdl code provides in a general power-on reset signal which can be used by other blocks to keep in reset
--								for a specific time
-- Remarks			:
-- Current Rev		: 		1.0	
-- History			:
---------------------------------------------------------------------------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
USE IEEE.NUMERIC_STD.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL; --for casting std_logic_vector to unsigned


entity POWER_ON_RESET_CONTROLLER is
	 Generic(Crystal_frequency : integer   := 25000000); --25000000 = 25MHz. For a fast simulation: make this value smaller
    Port ( CLOCK_IN : in  STD_LOGIC;
           NOT_RESET_OUT : out  STD_LOGIC := '0'); --keep the RESET signal active (low) on powerup
end POWER_ON_RESET_CONTROLLER;

architecture Behavioral of POWER_ON_RESET_CONTROLLER is

signal reset_counter 					: std_logic_vector(31 downto 0) := std_logic_vector(to_unsigned((Crystal_frequency/5), 32)); --makes a 200mS POR RESET signal

type statemachine is (st_reset,st_done);

-- Register to store the current state(s) or nextstate to go to
signal reset_controller_state : statemachine := st_reset; --intial state 

begin

por_reset_statemachine :	process(CLOCK_IN)
	begin
		if rising_edge(CLOCK_IN) then
			case reset_controller_state is
			
				when st_reset => --wait for a number of clk cycles (power on reset) (power-on reset), all output signals stay in the state defined in the port section of the entity
					reset_counter <= reset_counter -1;
					NOT_RESET_OUT <= '0';
					if (reset_counter = X"00000000") then
						reset_controller_state <= st_done;
					end if;
						
				when st_done => 
					NOT_RESET_OUT <= '1';
					reset_counter <= std_logic_vector(to_unsigned(0, 32));--stay here and keep reset counter to 0, noting to do
					
			end case;			
		end if;
	end process por_reset_statemachine;

end Behavioral;

