-----------------------------------------------------------------------------------------------------------------------------------
-- Engineer			: 		Dennis van Elteren, Maarssen, The Netherlands
-- 
-- Create Date		:    	February 24th 2015 
-- Design Name		: 		My FPGA vision system - Blink a led
-- Module Name		:    	Blinkled 
-- Target Devices	: 		xc3s200,xc6slx9
-- Tool versions	: 		ISE14.7
-- Description		: 		This vhdl code blinks the 4 leds on my FPGA board
--
-- Remarks			:
-- Current Rev		: 		1.0
-- History			: 		1.0	- 	File Created
-------------------------------------------------------------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity blinkled is
    Port ( 	LEDD1 : out  STD_LOGIC;
				LEDD2 : out  STD_LOGIC;
				LEDD3 : out  STD_LOGIC;
				LEDD4 : out  STD_LOGIC;
				CLK : in  STD_LOGIC);
end blinkled;

architecture Behavioral of blinkled is

constant N: integer:=48000000;
signal counter    : integer range 0 to N := 0;
signal ledd1onoff : std_logic := '0'; --start with led off
signal ledd2onoff : std_logic := '0'; 
signal ledd3onoff : std_logic := '0'; 
signal ledd4onoff : std_logic := '0'; 


begin

blinkled :	process(CLK)
begin
		if rising_edge(CLK) then
			counter <= counter +1; 
			
			if counter = N/4 then
				ledd4onoff		<= not ledd4onoff;
				LEDD4        <= ledd4onoff;
			elsif counter = N/2 then
				ledd3onoff		<= not ledd3onoff;
				LEDD3        <= ledd3onoff;
			elsif counter = (N/4)*3 then
				ledd2onoff		<= not ledd2onoff;
				LEDD2        <= ledd2onoff;
			elsif counter = N then
				counter <= 0;
				ledd1onoff		<= not ledd1onoff;
				LEDD1         <= ledd1onoff;
			end if;
			
		end if;
end process blinkled;


end Behavioral;

