---------------------------------------------------------------------------------------------------------------------------------
-- Engineer			: 		Dennis van Elteren, Maarssen, The Netherlands
-- 
-- Create Date		:    	February 24th 2015 
-- Design Name		: 		My FPGA vision system
-- Module Name		:    	clock_divider
-- Target Devices	: 		xc3s200,xc6slx9
-- Tool versions	: 		ISE14.7
-- Description		: 		This vhdl code divides the signal on the input CLK_IN so that the frequency becomes equal
--							   to what is specified for CLK_SLOW_FREQ. I wanted to do this with the DCM module (Digital Clock Manager)
--								but divisions seem to give problems with the DCM (multiplication maybe not)
-- Remarks			:
--
-- Current Rev		: 		1.0
-- History			: 		
-------------------------------------------------------------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity clock_divider is
    Port ( CLK_IN : in  STD_LOGIC;
           CLK_OUT : out  STD_LOGIC);
end clock_divider;

architecture Behavioral of clock_divider is
	 constant CLK_MASTER_FREQ: natural := 50000000; --50MHz will be put in
    constant CLK_SLOW_FREQ: natural := 25000000;--25MHz will be put out
    constant MAX_COUNT: natural := CLK_MASTER_FREQ/CLK_SLOW_FREQ;
    shared variable counter: natural := 0;
begin
	 clock_divider: process(CLK_IN)
    begin
        if rising_edge(CLK_IN) then
            counter := counter + 1;
            if (counter >= MAX_COUNT) then
                counter := 0;
                CLK_OUT <= '1';
            else
                CLK_OUT <= '0';
            end if;
        end if;
    end process clock_divider;

end Behavioral;

