------------------------------------------------------------------------------------------------------------------------------------------------------
-- Engineer					: 		Dennis van Elteren, Maarssen, The Netherlands
-- 
-- Create Date				:    	February 24th 2015 
-- Design Name				: 		My FPGA vision system
-- Module Name				:    	datasplitter 
-- Target Devices			: 		xc3s200,xc6slx9
-- Tool versions			: 		ISE14.7
-- Description				: 		Bidirectional data port with adjustable Width, modes are:
--										DATA to DATA_OUT when DIR = 1, DATA_IN to DATA when DIR = 0
--
-- Remarks					: 		Behavioural sim = OK. Post-Route sim = ok with 1 remark: data_out is defined as an output
--										When DIR=1 then data_out always follows "data". During the period where "data" = high-Z (ZZZZZZZZ) data_out
--										shows violations. These are no severe errors, they occur solely because a port defined as output can not handle the 
--										high-Z state
--
-- Current Rev				: 		1.0
-- History					: 		
--
------------------------------------------------------------------------------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity datasplitter is
	 Generic ( Width             : integer   :=   16  );      -- data bus width
              
    Port ( DATA : inout  STD_LOGIC_VECTOR (Width-1 downto 0);
           DATA_OUT: out  STD_LOGIC_VECTOR (Width-1 downto 0);
           DATA_IN : in  STD_LOGIC_VECTOR (Width-1 downto 0);
           DIR : in  STD_LOGIC);
end datasplitter;


architecture Behavioral of datasplitter is
begin	
	DATA_OUT <= DATA; --read the port, no matter what DIR is, DATA_OUT always follows DATA			
	DATA <= DATA_IN when DIR = '1' else (others => 'Z' );--drive the port aka read it      
end Behavioral;

